aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/lib/transport/error_utils.h
diff options
context:
space:
mode:
authorGravatar ncteisen <ncteisen@gmail.com>2017-11-13 08:02:35 -0800
committerGravatar ncteisen <ncteisen@gmail.com>2017-11-13 08:02:35 -0800
commit40737d67ee93f3c60be1f0ff6486d6f045646312 (patch)
treefa41a4f70bc29d45be6cb8f532d71cb9525019f0 /src/core/lib/transport/error_utils.h
parent396d26539af8ce8ff8b737b574800ab814f0e625 (diff)
Add error string to recv status API
Diffstat (limited to 'src/core/lib/transport/error_utils.h')
-rw-r--r--src/core/lib/transport/error_utils.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/core/lib/transport/error_utils.h b/src/core/lib/transport/error_utils.h
index 690e42058a..d47c4f2a3b 100644
--- a/src/core/lib/transport/error_utils.h
+++ b/src/core/lib/transport/error_utils.h
@@ -30,13 +30,15 @@ extern "C" {
/// A utility function to get the status code and message to be returned
/// to the application. If not set in the top-level message, looks
/// through child errors until it finds the first one with these attributes.
/// All attributes are pulled from the same child error. If any of the
/// attributes (code, msg, http_status) are unneeded, they can be passed as
/// NULL.
void grpc_error_get_status(grpc_exec_ctx* exec_ctx, grpc_error* error,
grpc_millis deadline, grpc_status_code* code,
grpc_slice* slice,
- grpc_http2_error_code* http_status);
+ grpc_http2_error_code* http_status,
+ const char** full_error_details);
/// A utility function to check whether there is a clear status code that
/// doesn't need to be guessed in \a error. This means that \a error or some
@@ -30,13 +30,15 @@ extern "C" {
/// to the application. If not set in the top-level message, looks
/// through child errors until it finds the first one with these attributes.
-/// All attributes are pulled from the same child error. If any of the
-/// attributes (code, msg, http_status) are unneeded, they can be passed as
+/// All attributes are pulled from the same child error. full_error_details will
+/// be populated with the entire error string. If any of the attributes (code,
+/// msg, http_status, full_error_details) are unneeded, they can be passed as
/// NULL.
void grpc_error_get_status(grpc_exec_ctx* exec_ctx, grpc_error* error,